CODE_EXTENSIONS = {
    # Web/Frontend
    ".js",
    ".jsx",
    ".ts",
    ".tsx",
    ".vue",
    ".svelte",
    ".html",
    ".css",
    ".scss",
    ".sass",
    ".less",
    # Backend/General Purpose
    ".py",
    ".java",
    ".cpp",
    ".c",
    ".cs",
    ".go",
    ".rs",
    ".rb",
    ".php",
    ".scala",
    ".kt",
    ".kts",
    ".groovy",
    ".swift",
    ".m",
    ".h",
    ".hpp",
    ".cxx",
    ".cc",
    ".hh",
    ".perl",
    ".pl",
    ".pm",
    # Shell/Scripts
    ".sh",
    ".bash",
    ".zsh",
    ".fish",
    ".ps1",
    ".bat",
    ".cmd",
    # Config
    ".toml",
    ".ini",
    ".json",
    ".yaml",
    ".yml",
    # Templates
    ".j2",
    ".jinja",
    ".jinja2",
    ".tmpl",
    ".tpl",
    # Documentation/Markup
    ".md",
    ".mdx",
    ".rst",
    ".tex",
    ".adoc",
    ".asciidoc",
    ".wiki",
    ".org",
    ".pod",
    ".rdoc",
    ".textile",
    ".creole",
    ".wiki",
    ".dokuwiki",
    ".mediawiki",
    # Other
    ".r",
    ".lua",
    ".dart",
    ".elm",
    ".ex",
    ".exs",
    ".erl",
    ".hrl",
    ".clj",
    ".cls",
    ".asm",
    ".s",
    ".nim",
    ".cr",
    ".ml",
    ".mli",
    ".fs",
    ".fsx",
}
